"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = __importDefault(require("yargs"));
const schema_generator_1 = require("./schema-generator");
const test_generator_1 = require("./testGenerator/test-generator");
const driver_schema_generator_1 = require("./driverSchema/driver-schema-generator");
async function main() {
    const argv = await yargs_1.default
        .command('schema', 'Generates schema from the php driver definitions')
        .command('tests', 'Generates tests from the php driver definitions and the docs examples')
        .command('driver-schema', 'Updates the php driver definitions with the schema for the tests', {
        category: {
            type: 'string',
            choices: ['accumulator', 'expression', 'query', 'search', 'stage'],
            description: 'The category of the operator to update. If not provided, all categories will be updated.',
        },
        operator: {
            type: 'string',
            description: 'The operator to update the schema for. If not provided, all operators will be updated.',
        },
    })
        .demandCommand(1, 'A command must be provided')
        .help().argv;
    const [command] = argv._.map(String);
    const categoryFilter = argv.category;
    const operatorFilter = argv.operator;
    let generator;
    switch (command) {
        case 'schema':
            generator = new schema_generator_1.SchemaGenerator();
            break;
        case 'tests':
            generator = new test_generator_1.TestGenerator();
            break;
        case 'driver-schema':
            generator = new driver_schema_generator_1.DriverSchemaGenerator();
            break;
        default:
            throw new Error(`Unknown command: ${command}. See '${argv.$0} --help' for more information.`);
    }
    await generator.generate(categoryFilter, operatorFilter);
}
main().catch((err) => {
    console.error(err);
    process.exit(1);
});
//# sourceMappingURL=cli.js.map